@@ -78,7 +78,7 @@ static const GOptionEntry options[] = {
 	  NULL },
 
 	{ "default-dir", '\0', 0, G_OPTION_ARG_STRING, &arg_default_dir,
-	  N_("Default folder to use for the '--add' and '--extract' commands"),
+	  N_("Default folder to use for the “--add” and “--extract” commands"),
 	  N_("FOLDER") },
 
 	{ "force", '\0', 0, G_OPTION_ARG_NONE, &ForceDirectoryCreation,
@@ -296,7 +296,7 @@ handle_method_call (GDBusConnection       *connection,
 		g_signal_connect (window, "ready", G_CALLBACK (window_ready_cb), invocation);
 
 		fr_window_batch_new (FR_WINDOW (window), C_("Window title", "Extract archive"));
-		fr_window_batch__extract (FR_WINDOW (window), archive, destination);
+		fr_window_batch__extract (FR_WINDOW (window), archive, destination, use_progress_dialog);
 		fr_window_batch_append_action (FR_WINDOW (window), FR_BATCH_ACTION_QUIT, NULL, NULL);
 		fr_window_batch_start (FR_WINDOW (window));
 
@@ -322,7 +322,7 @@ handle_method_call (GDBusConnection       *connection,
 		g_signal_connect (window, "ready", G_CALLBACK (window_ready_cb), invocation);
 
 		fr_window_batch_new (FR_WINDOW (window), C_("Window title", "Extract archive"));
-		fr_window_batch__extract_here (FR_WINDOW (window), archive);
+		fr_window_batch__extract_here (FR_WINDOW (window), archive, use_progress_dialog);
 		fr_window_batch_append_action (FR_WINDOW (window), FR_BATCH_ACTION_QUIT, NULL, NULL);
 		fr_window_batch_start (FR_WINDOW (window));
 
@@ -342,28 +342,29 @@ static const GDBusInterfaceVTable interface_vtable = {
 /* -- main application -- */
 
 
-G_DEFINE_TYPE (FrApplication, fr_application, GTK_TYPE_APPLICATION)
-
-
-struct _FrApplicationPrivate {
-	GDBusNodeInfo *introspection_data;
-	guint          owner_id;
-	GSettings     *listing_settings;
-	GSettings     *ui_settings;
+struct _FrApplication {
+	GtkApplication  parent_instance;
+	GDBusNodeInfo  *introspection_data;
+	guint           owner_id;
+	GSettings      *listing_settings;
+	GSettings      *ui_settings;
 };
 
 
+G_DEFINE_TYPE (FrApplication, fr_application, GTK_TYPE_APPLICATION)
+
+
 static void
 fr_application_finalize (GObject *object)
 {
 	FrApplication *self = FR_APPLICATION (object);
 
-	if (self->priv->introspection_data != NULL)
-		g_dbus_node_info_unref (self->priv->introspection_data);
-	if (self->priv->owner_id != 0)
-		g_bus_unown_name (self->priv->owner_id);
-	_g_object_unref (self->priv->listing_settings);
-	_g_object_unref (self->priv->ui_settings);
+	if (self->introspection_data != NULL)
+		g_dbus_node_info_unref (self->introspection_data);
+	if (self->owner_id != 0)
+		g_bus_unown_name (self->owner_id);
+	_g_object_unref (self->listing_settings);
+	_g_object_unref (self->ui_settings);
 
 	release_data ();
 
@@ -382,7 +383,7 @@ on_bus_acquired_for_archive_manager (GDBusConnection *connection,
 
 	registration_id = g_dbus_connection_register_object (connection,
 							     "/org/gnome/ArchiveManager1",
-							     self->priv->introspection_data->interfaces[0],
+							     self->introspection_data->interfaces[0],
 							     &interface_vtable,
 							     NULL,
 							     NULL,  /* user_data_free_func */
@@ -419,9 +420,9 @@ fr_application_register_archive_manager_service (FrApplication *self)
 	if (g_input_stream_read_all (stream, buffer, size, &bytes_read, NULL, NULL)) {
 		buffer[bytes_read] = '\0';
 
-		self->priv->introspection_data = g_dbus_node_info_new_for_xml ((gchar *) buffer, &error);
-		if (self->priv->introspection_data != NULL) {
-			self->priv->owner_id = g_bus_own_name (G_BUS_TYPE_SESSION,
+		self->introspection_data = g_dbus_node_info_new_for_xml ((gchar *) buffer, &error);
+		if (self->introspection_data != NULL) {
+			self->owner_id = g_bus_own_name (G_BUS_TYPE_SESSION,
 							 "org.gnome.ArchiveManager1",
 							 G_BUS_NAME_OWNER_FLAGS_NONE,
 							 on_bus_acquired_for_archive_manager,
@@ -482,7 +483,7 @@ fr_application_create_option_context (void)
 	GOptionContext *context;
 	static gsize    initialized = FALSE;
 
-	context = g_option_context_new (N_("- Create and modify an archive"));
+	context = g_option_context_new (N_("— Create and modify an archive"));
 	g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
 	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 	g_option_context_set_ignore_unknown_options (context, TRUE);
@@ -604,13 +605,16 @@ fr_application_command_line (GApplication            *application,
 
 		fr_window_batch_new (FR_WINDOW (window), C_("Window title", "Extract archive"));
 		while ((archive = remaining_args[i++]) != NULL) {
-			GFile *file;
+			GFile    *file;
+			gboolean  last_archive;
 
 			file = g_application_command_line_create_file_for_arg (command_line, archive);
+			last_archive = (remaining_args[i] == NULL);
+
 			if (arg_extract_here == 1)
-				fr_window_batch__extract_here (FR_WINDOW (window), file);
+				fr_window_batch__extract_here (FR_WINDOW (window), file, arg_notify && last_archive);
 			else
-				fr_window_batch__extract (FR_WINDOW (window), file, extraction_destination);
+				fr_window_batch__extract (FR_WINDOW (window), file, extraction_destination, arg_notify && last_archive);
 
 			g_object_unref (file);
 		}
@@ -705,8 +709,6 @@ fr_application_class_init (FrApplicationClass *klass)
 	GObjectClass      *object_class;
 	GApplicationClass *application_class;
 
-	g_type_class_add_private (klass, sizeof (FrApplicationPrivate));
-
 	object_class = G_OBJECT_CLASS (klass);
 	object_class->finalize = fr_application_finalize;
 
@@ -721,11 +723,10 @@ fr_application_class_init (FrApplicationClass *klass)
 static void
 fr_application_init (FrApplication *self)
 {
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, FR_TYPE_APPLICATION, FrApplicationPrivate);
-	self->priv->owner_id = 0;
-	self->priv->introspection_data = NULL;
-	self->priv->listing_settings = g_settings_new (FILE_ROLLER_SCHEMA_LISTING);
-	self->priv->ui_settings = g_settings_new (FILE_ROLLER_SCHEMA_UI);
+	self->owner_id = 0;
+	self->introspection_data = NULL;
+	self->listing_settings = g_settings_new (FILE_ROLLER_SCHEMA_LISTING);
+	self->ui_settings = g_settings_new (FILE_ROLLER_SCHEMA_UI);
 }
 
 
@@ -744,9 +745,9 @@ fr_application_get_settings (FrApplication *app,
 			     const char    *schema)
 {
 	if (strcmp (schema, FILE_ROLLER_SCHEMA_LISTING) == 0)
-		return app->priv->listing_settings;
+		return app->listing_settings;
 	else if (strcmp (schema, FILE_ROLLER_SCHEMA_UI) == 0)
-		return app->priv->ui_settings;
+		return app->ui_settings;
 	else
 		return NULL;
 }
