@@ -67,30 +67,32 @@ fr_archive_libarchive_finalize (GObject *object)
 
 
 const char *libarchiver_mime_types[] = {
-		"application/vnd.debian.binary-package",
-		"application/vnd.ms-cab-compressed",
-		"application/x-7z-compressed",
-		"application/x-ar",
-		"application/x-bzip-compressed-tar",
-		"application/x-cbr",
-		"application/x-cbz",
-		"application/x-cd-image",
-		"application/x-compressed-tar",
-		"application/x-cpio",
-		"application/x-deb",
-		"application/x-lha",
-		"application/x-lrzip-compressed-tar",
-		"application/x-lzip-compressed-tar",
-		"application/x-lzma-compressed-tar",
-		"application/x-lzop-compressed-tar",
-		"application/x-rar",
-		"application/x-rpm",
-		"application/x-tar",
-		"application/x-tarz",
-		"application/x-xar",
-		"application/x-xz-compressed-tar",
-		"application/zip",
-		NULL };
+	"application/epub+zip",
+	"application/vnd.debian.binary-package",
+	"application/vnd.ms-cab-compressed",
+	"application/x-7z-compressed",
+	"application/x-ar",
+	"application/x-bzip-compressed-tar",
+	"application/x-cbr",
+	"application/x-cbz",
+	"application/x-cd-image",
+	"application/x-compressed-tar",
+	"application/x-cpio",
+	"application/x-deb",
+	"application/x-lha",
+	"application/x-lrzip-compressed-tar",
+	"application/x-lzip-compressed-tar",
+	"application/x-lzma-compressed-tar",
+	"application/x-lzop-compressed-tar",
+	"application/x-rar",
+	"application/x-rpm",
+	"application/x-tar",
+	"application/x-tarz",
+	"application/x-xar",
+	"application/x-xz-compressed-tar",
+	"application/zip",
+	NULL
+};
 
 
 static const char **
